.. Copyright (C) 2019 Rainer 'rei' Schuth <devel@reixd.net>
.. Copyright (C) 2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops.postldap:

debops.postldap
===============

.. include:: man_description.rst
   :start-line: 7

.. toctree::
   :maxdepth: 3

   getting-started
   guides
   defaults/main
   ldap-dit

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/postldap/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
